Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1069)

Unified Diff: webrtc/config.h

Issue 2391963002: Rename FecConfig to UlpfecConfig in config.h. (Closed)
Patch Set: Rebase. Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/call/rampup_tests.cc ('k') | webrtc/config.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/config.h
diff --git a/webrtc/config.h b/webrtc/config.h
index 0231cb56827500331329a8d4e6a5ecd2e3e0abfc..a6778715d87f634692a63b59aac64d3010ec73c6 100644
--- a/webrtc/config.h
+++ b/webrtc/config.h
@@ -35,10 +35,10 @@ struct NackConfig {
int rtp_history_ms;
};
-// Settings for forward error correction, see RFC 5109 for details. Set the
-// payload types to '-1' to disable.
-struct FecConfig {
- FecConfig()
+// Settings for ULPFEC forward error correction.
+// Set the payload types to '-1' to disable.
+struct UlpfecConfig {
+ UlpfecConfig()
: ulpfec_payload_type(-1),
red_payload_type(-1),
red_rtx_payload_type(-1) {}
« no previous file with comments | « webrtc/call/rampup_tests.cc ('k') | webrtc/config.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698